@@ -15,15 +15,18 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """
 Example Airflow DAG that uses Google AutoML services.
 """
+from __future__ import annotations
+
 import os
 from copy import deepcopy
-from typing import Dict, List
+from datetime import datetime
+from typing import cast
 
 from airflow import models
+from airflow.models.xcom_arg import XComArg
 from airflow.providers.google.cloud.hooks.automl import CloudAutoMLHook
 from airflow.providers.google.cloud.operators.automl import (
     AutoMLBatchPredictOperator,
@@ -40,7 +43,8 @@ from airflow.providers.google.cloud.operators.automl import (
     AutoMLTablesUpdateDatasetOperator,
     AutoMLTrainModelOperator,
 )
-from airflow.utils.dates import days_ago
+
+START_DATE = datetime(2021, 1, 1)
 
 GCP_PROJECT_ID = os.environ.get("GCP_PROJECT_ID", "your-project-id")
 GCP_AUTOML_LOCATION = os.environ.get("GCP_AUTOML_LOCATION", "us-central1")
@@ -71,7 +75,7 @@ IMPORT_INPUT_CONFIG = {"gcs_source": {"input_uris": [GCP_AUTOML_DATASET_BUCKET]}
 extract_object_id = CloudAutoMLHook.extract_object_id
 
 
-def get_target_column_spec(columns_specs: List[Dict], column_name: str) -> str:
+def get_target_column_spec(columns_specs: list[dict], column_name: str) -> str:
     """
     Using column name returns spec of the column.
     """
@@ -84,8 +88,8 @@ def get_target_column_spec(columns_specs: List[Dict], column_name: str) -> str:
 # Example DAG to create dataset, train model_id and deploy it.
 with models.DAG(
     "example_create_and_deploy",
-    schedule_interval='@once',  # Override to match your needs
-    start_date=days_ago(1),
+    start_date=START_DATE,
+    catchup=False,
     user_defined_macros={
         "get_target_column_spec": get_target_column_spec,
         "target": TARGET,
@@ -101,7 +105,7 @@ with models.DAG(
         project_id=GCP_PROJECT_ID,
     )
 
-    dataset_id = create_dataset_task.output['dataset_id']
+    dataset_id = cast(str, XComArg(create_dataset_task, key='dataset_id'))
     # [END howto_operator_automl_create_dataset]
 
     MODEL["dataset_id"] = dataset_id
@@ -156,7 +160,7 @@ with models.DAG(
         project_id=GCP_PROJECT_ID,
     )
 
-    model_id = create_model_task.output['model_id']
+    model_id = cast(str, XComArg(create_model_task, key='model_id'))
     # [END howto_operator_automl_create_model]
 
     # [START howto_operator_automl_delete_model]
@@ -196,18 +200,18 @@ with models.DAG(
 # Example DAG for AutoML datasets operations
 with models.DAG(
     "example_automl_dataset",
-    schedule_interval='@once',  # Override to match your needs
-    start_date=days_ago(1),
+    start_date=START_DATE,
+    catchup=False,
     user_defined_macros={"extract_object_id": extract_object_id},
 ) as example_dag:
-    create_dataset_task = AutoMLCreateDatasetOperator(
+    create_dataset_task2 = AutoMLCreateDatasetOperator(
         task_id="create_dataset_task",
         dataset=DATASET,
         location=GCP_AUTOML_LOCATION,
         project_id=GCP_PROJECT_ID,
     )
 
-    dataset_id = create_dataset_task.output['dataset_id']
+    dataset_id = cast(str, XComArg(create_dataset_task2, key='dataset_id'))
 
     import_dataset_task = AutoMLImportDataOperator(
         task_id="import_dataset_task",
@@ -264,8 +268,8 @@ with models.DAG(
 
 with models.DAG(
     "example_gcp_get_deploy",
-    schedule_interval='@once',  # Override to match your needs
-    start_date=days_ago(1),
+    start_date=START_DATE,
+    catchup=False,
     tags=["example"],
 ) as get_deploy_dag:
     # [START howto_operator_get_model]
@@ -289,8 +293,8 @@ with models.DAG(
 
 with models.DAG(
     "example_gcp_predict",
-    schedule_interval='@once',  # Override to match your needs
-    start_date=days_ago(1),
+    start_date=START_DATE,
+    catchup=False,
     tags=["example"],
 ) as predict_dag:
     # [START howto_operator_prediction]
