@@ -15,13 +15,17 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """
 Example Airflow DAG that uses Google AutoML services.
 """
+from __future__ import annotations
+
 import os
+from datetime import datetime
+from typing import cast
 
 from airflow import models
+from airflow.models.xcom_arg import XComArg
 from airflow.providers.google.cloud.hooks.automl import CloudAutoMLHook
 from airflow.providers.google.cloud.operators.automl import (
     AutoMLCreateDatasetOperator,
@@ -30,11 +34,12 @@ from airflow.providers.google.cloud.operators.automl import (
     AutoMLImportDataOperator,
     AutoMLTrainModelOperator,
 )
-from airflow.utils.dates import days_ago
 
 GCP_PROJECT_ID = os.environ.get("GCP_PROJECT_ID", "your-project-id")
 GCP_AUTOML_LOCATION = os.environ.get("GCP_AUTOML_LOCATION", "us-central1")
-GCP_AUTOML_TRANSLATION_BUCKET = os.environ.get("GCP_AUTOML_TRANSLATION_BUCKET", "gs://project-vcm/file")
+GCP_AUTOML_TRANSLATION_BUCKET = os.environ.get(
+    "GCP_AUTOML_TRANSLATION_BUCKET", "gs://INVALID BUCKET NAME/file"
+)
 
 # Example values
 DATASET_ID = "TRL123456789"
@@ -63,8 +68,8 @@ extract_object_id = CloudAutoMLHook.extract_object_id
 # Example DAG for AutoML Translation
 with models.DAG(
     "example_automl_translation",
-    schedule_interval=None,  # Override to match your needs
-    start_date=days_ago(1),
+    start_date=datetime(2021, 1, 1),
+    catchup=False,
     user_defined_macros={"extract_object_id": extract_object_id},
     tags=['example'],
 ) as example_dag:
@@ -72,7 +77,7 @@ with models.DAG(
         task_id="create_dataset_task", dataset=DATASET, location=GCP_AUTOML_LOCATION
     )
 
-    dataset_id = '{{ task_instance.xcom_pull("create_dataset_task", key="dataset_id") }}'
+    dataset_id = cast(str, XComArg(create_dataset_task, key="dataset_id"))
 
     import_dataset_task = AutoMLImportDataOperator(
         task_id="import_dataset_task",
@@ -85,7 +90,7 @@ with models.DAG(
 
     create_model = AutoMLTrainModelOperator(task_id="create_model", model=MODEL, location=GCP_AUTOML_LOCATION)
 
-    model_id = "{{ task_instance.xcom_pull('create_model', key='model_id') }}"
+    model_id = cast(str, XComArg(create_model, key="model_id"))
 
     delete_model_task = AutoMLDeleteModelOperator(
         task_id="delete_model_task",
@@ -101,4 +106,11 @@ with models.DAG(
         project_id=GCP_PROJECT_ID,
     )
 
-    create_dataset_task >> import_dataset_task >> create_model >> delete_model_task >> delete_datasets_task
+    import_dataset_task >> create_model
+    delete_model_task >> delete_datasets_task
+
+    # Task dependencies created via `XComArgs`:
+    #   create_dataset_task >> import_dataset_task
+    #   create_dataset_task >> create_model
+    #   create_model >> delete_model_task
+    #   create_dataset_task >> delete_datasets_task
