@@ -17,7 +17,10 @@
 """
 Example Airflow DAG that shows how to use Google Dataprep.
 """
+from __future__ import annotations
+
 import os
+from datetime import datetime
 
 from airflow import models
 from airflow.providers.google.cloud.operators.dataprep import (
@@ -25,7 +28,6 @@ from airflow.providers.google.cloud.operators.dataprep import (
     DataprepGetJobsForJobGroupOperator,
     DataprepRunJobGroupOperator,
 )
-from airflow.utils import dates
 
 DATAPREP_JOB_ID = int(os.environ.get('DATAPREP_JOB_ID', 12345677))
 DATAPREP_JOB_RECIPE_ID = int(os.environ.get('DATAPREP_JOB_RECIPE_ID', 12345677))
@@ -52,8 +54,8 @@ DATA = {
 
 with models.DAG(
     "example_dataprep",
-    schedule_interval='@once',
-    start_date=dates.days_ago(1),  # Override to match your needs
+    start_date=datetime(2021, 1, 1),  # Override to match your needs
+    catchup=False,
 ) as dag:
     # [START how_to_dataprep_run_job_group_operator]
     run_job_group = DataprepRunJobGroupOperator(task_id="run_job_group", body_request=DATA)
