@@ -15,7 +15,6 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """
 Example Airflow DAG that creates, gets, updates and deletes Products and Product Sets in the Google Cloud
 Vision service.
@@ -30,6 +29,7 @@ This DAG relies on the following OS environment variables
 * GCP_VISION_ANNOTATE_IMAGE_URL - A link to the bucket that contains the file to be annotated.
 
 """
+from __future__ import annotations
 
 import os
 from datetime import datetime
@@ -57,6 +57,8 @@ from airflow.providers.google.cloud.operators.vision import (
 )
 
 # [START howto_operator_vision_retry_import]
+
+
 from google.api_core.retry import Retry  # isort:skip
 
 # [END howto_operator_vision_retry_import]
@@ -116,7 +118,6 @@ DETECT_IMAGE = {"source": {"image_uri": GCP_VISION_ANNOTATE_IMAGE_URL}}
 
 with models.DAG(
     'example_gcp_vision_autogenerated_id',
-    schedule_interval='@once',
     start_date=START_DATE,
     catchup=False,
 ) as dag_autogenerated_id:
@@ -274,7 +275,6 @@ with models.DAG(
 
 with models.DAG(
     'example_gcp_vision_explicit_id',
-    schedule_interval='@once',
     start_date=START_DATE,
     catchup=False,
 ) as dag_explicit_id:
@@ -442,7 +442,6 @@ with models.DAG(
 
 with models.DAG(
     'example_gcp_vision_annotate_image',
-    schedule_interval='@once',
     start_date=START_DATE,
     catchup=False,
 ) as dag_annotate_image:
