@@ -15,11 +15,13 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
 """This module contains a BigQuery Hook."""
-from copy import copy
-from typing import Optional, Sequence, Tuple, Union
+from __future__ import annotations
 
+from copy import copy
+from typing import Optional, Sequence
+
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
 from google.cloud.bigquery_datatransfer_v1 import DataTransferServiceClient
 from google.cloud.bigquery_datatransfer_v1.types import (
@@ -51,9 +53,9 @@ class BiqQueryDataTransferServiceHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        location: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        location: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
@@ -63,7 +65,7 @@ class BiqQueryDataTransferServiceHook(GoogleBaseHook):
         self.location = location
 
     @staticmethod
-    def _disable_auto_scheduling(config: Union[dict, TransferConfig]) -> TransferConfig:
+    def _disable_auto_scheduling(config: dict | TransferConfig) -> TransferConfig:
         """
         In the case of Airflow, the customer needs to create a transfer config
         with the automatic scheduling disabled (UI, CLI or an Airflow operator) and
@@ -81,10 +83,7 @@ class BiqQueryDataTransferServiceHook(GoogleBaseHook):
                 schedule_options["disable_auto_scheduling"] = True
         else:
             new_config["schedule_options"] = {"disable_auto_scheduling": True}
-        # HACK: TransferConfig.to_dict returns invalid representation
-        # See: https://github.com/googleapis/python-bigquery-datatransfer/issues/90
-        if isinstance(new_config.get('user_id'), str):
-            new_config['user_id'] = int(new_config['user_id'])
+
         return TransferConfig(**new_config)
 
     def get_conn(self) -> DataTransferServiceClient:
@@ -96,19 +95,19 @@ class BiqQueryDataTransferServiceHook(GoogleBaseHook):
         """
         if not self._conn:
             self._conn = DataTransferServiceClient(
-                credentials=self._get_credentials(), client_info=CLIENT_INFO
+                credentials=self.get_credentials(), client_info=CLIENT_INFO
             )
         return self._conn
 
     @GoogleBaseHook.fallback_to_default_project_id
     def create_transfer_config(
         self,
-        transfer_config: Union[dict, TransferConfig],
+        transfer_config: dict | TransferConfig,
         project_id: str = PROVIDE_PROJECT_ID,
-        authorization_code: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        authorization_code: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> TransferConfig:
         """
         Creates a new data transfer configuration.
@@ -148,9 +147,9 @@ class BiqQueryDataTransferServiceHook(GoogleBaseHook):
         self,
         transfer_config_id: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
         Deletes transfer configuration.
@@ -170,7 +169,7 @@ class BiqQueryDataTransferServiceHook(GoogleBaseHook):
         client = self.get_conn()
         project = f"projects/{project_id}"
         if self.location:
-            project = f"/{project}/locations/{self.location}"
+            project = f"{project}/locations/{self.location}"
 
         name = f"{project}/transferConfigs/{transfer_config_id}"
         return client.delete_transfer_config(
@@ -182,11 +181,11 @@ class BiqQueryDataTransferServiceHook(GoogleBaseHook):
         self,
         transfer_config_id: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        requested_time_range: Optional[dict] = None,
-        requested_run_time: Optional[dict] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        requested_time_range: dict | None = None,
+        requested_run_time: dict | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> StartManualTransferRunsResponse:
         """
         Start manual transfer runs to be executed now with schedule_time equal
@@ -236,9 +235,9 @@ class BiqQueryDataTransferServiceHook(GoogleBaseHook):
         run_id: str,
         transfer_config_id: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ) -> TransferRun:
         """
         Returns information about the particular transfer run.
