@@ -15,11 +15,23 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Hooks for Cloud Memorystore service"""
-from typing import Dict, Optional, Sequence, Tuple, Union
+"""
+Hooks for Cloud Memorystore service.
+
+.. spelling::
+
+    DataProtectionMode
+    FieldMask
+    pb
+    memcache
+"""
+from __future__ import annotations
+
+from typing import Sequence
 
 from google.api_core import path_template
 from google.api_core.exceptions import NotFound
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
 from google.cloud.memcache_v1beta2 import CloudMemcacheClient
 from google.cloud.memcache_v1beta2.types import cloud_memcache
@@ -45,11 +57,9 @@ class CloudMemorystoreHook(GoogleBaseHook):
     keyword arguments rather than positional.
 
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -58,43 +68,39 @@ class CloudMemorystoreHook(GoogleBaseHook):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account.
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
-        self._client: Optional[CloudRedisClient] = None
+        self._client: CloudRedisClient | None = None
 
     def get_conn(self) -> CloudRedisClient:
         """Retrieves client library object that allow access to Cloud Memorystore service."""
         if not self._client:
-            self._client = CloudRedisClient(credentials=self._get_credentials())
+            self._client = CloudRedisClient(credentials=self.get_credentials())
         return self._client
 
     @staticmethod
     def _append_label(instance: Instance, key: str, val: str) -> Instance:
         """
-        Append labels to provided Instance type
+        Append labels to provided Instance type.
 
         Labels must fit the regex ``[a-z]([-a-z0-9]*[a-z0-9])?`` (current
          airflow version string follows semantic versioning spec: x.y.z).
 
         :param instance: The proto to append resource_label airflow
             version to
-        :type instance: google.cloud.container_v1.types.Cluster
         :param key: The key label
-        :type key: str
         :param val:
-        :type val: str
         :return: The cluster proto updated with new label
         """
         val = val.replace(".", "-").replace("+", "-")
@@ -106,11 +112,11 @@ class CloudMemorystoreHook(GoogleBaseHook):
         self,
         location: str,
         instance_id: str,
-        instance: Union[Dict, Instance],
+        instance: dict | Instance,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Creates a Redis instance based on the specified tier and memory size.
@@ -119,7 +125,6 @@ class CloudMemorystoreHook(GoogleBaseHook):
         <https://cloud.google.com/compute/docs/networks-and-firewalls#networks>`__.
 
         :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-        :type location: str
         :param instance_id: Required. The logical name of the Redis instance in the customer project with the
             following restrictions:
 
@@ -128,23 +133,17 @@ class CloudMemorystoreHook(GoogleBaseHook):
             -  Must be between 1-40 characters.
             -  Must end with a number or a letter.
             -  Must be unique within the customer project / location
-        :type instance_id: str
         :param instance: Required. A Redis [Instance] resource
 
             If a dict is provided, it must be of the same form as the protobuf message
             :class:`~google.cloud.redis_v1.types.Instance`
-        :type instance: Union[Dict, google.cloud.redis_v1.types.Instance]
         :param project_id: Project ID of the project that contains the instance. If set
             to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             ``retry`` is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
         if isinstance(instance, dict):
@@ -184,28 +183,22 @@ class CloudMemorystoreHook(GoogleBaseHook):
         location: str,
         instance: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Deletes a specific Redis instance.  Instance stops serving and data is deleted.
 
         :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-        :type location: str
         :param instance: The logical name of the Redis instance in the customer project.
-        :type instance: str
         :param project_id: Project ID of the project that contains the instance. If set
             to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             ``retry`` is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/instances/{instance}"
@@ -235,11 +228,11 @@ class CloudMemorystoreHook(GoogleBaseHook):
         self,
         location: str,
         instance: str,
-        output_config: Union[Dict, OutputConfig],
+        output_config: dict | OutputConfig,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Export Redis instance data into a Redis RDB format file in Cloud Storage.
@@ -247,25 +240,18 @@ class CloudMemorystoreHook(GoogleBaseHook):
         Redis will continue serving during this operation.
 
         :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-        :type location: str
         :param instance: The logical name of the Redis instance in the customer project.
-        :type instance: str
         :param output_config: Required. Specify data to be exported.
 
             If a dict is provided, it must be of the same form as the protobuf message
             :class:`~google.cloud.redis_v1.types.OutputConfig`
-        :type output_config: Union[Dict, google.cloud.redis_v1.types.OutputConfig]
         :param project_id: Project ID of the project that contains the instance. If set
             to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             ``retry`` is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/instances/{instance}"
@@ -286,33 +272,28 @@ class CloudMemorystoreHook(GoogleBaseHook):
         instance: str,
         data_protection_mode: FailoverInstanceRequest.DataProtectionMode,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
+        Failover of the primary node to current replica node.
+
         Initiates a failover of the primary node to current replica node for a specific STANDARD tier Cloud
         Memorystore for Redis instance.
 
         :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-        :type location: str
         :param instance: The logical name of the Redis instance in the customer project.
-        :type instance: str
         :param data_protection_mode: Optional. Available data protection modes that the user can choose. If
             it's unspecified, data protection mode will be LIMITED_DATA_LOSS by default.
-        :type data_protection_mode: google.cloud.redis_v1.gapic.enums.FailoverInstanceRequest
             .DataProtectionMode
         :param project_id: Project ID of the project that contains the instance. If set
             to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             ``retry`` is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/instances/{instance}"
@@ -333,28 +314,22 @@ class CloudMemorystoreHook(GoogleBaseHook):
         location: str,
         instance: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Gets the details of a specific Redis instance.
 
         :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-        :type location: str
         :param instance: The logical name of the Redis instance in the customer project.
-        :type instance: str
         :param project_id: Project ID of the project that contains the instance. If set
             to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             ``retry`` is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/instances/{instance}"
@@ -372,11 +347,11 @@ class CloudMemorystoreHook(GoogleBaseHook):
         self,
         location: str,
         instance: str,
-        input_config: Union[Dict, InputConfig],
+        input_config: dict | InputConfig,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Import a Redis RDB snapshot file from Cloud Storage into a Redis instance.
@@ -385,25 +360,18 @@ class CloudMemorystoreHook(GoogleBaseHook):
         When complete, the instance will contain only data from the imported file.
 
         :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-        :type location: str
         :param instance: The logical name of the Redis instance in the customer project.
-        :type instance: str
         :param input_config: Required. Specify data to be imported.
 
             If a dict is provided, it must be of the same form as the protobuf message
             :class:`~google.cloud.redis_v1.types.InputConfig`
-        :type input_config: Union[Dict, google.cloud.redis_v1.types.InputConfig]
         :param project_id: Project ID of the project that contains the instance. If set
             to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             ``retry`` is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
         name = f"projects/{project_id}/locations/{location}/instances/{instance}"
@@ -423,34 +391,27 @@ class CloudMemorystoreHook(GoogleBaseHook):
         location: str,
         page_size: int,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
-        Lists all Redis instances owned by a project in either the specified location (region) or all
-        locations.
+        List Redis instances owned by a project at the specified location (region) or all locations.
 
         :param location: The location of the Cloud Memorystore instance (for example europe-west1)
 
                 If it is specified as ``-`` (wildcard), then all regions available to the project are
                 queried, and the results are aggregated.
-        :type location: str
         :param page_size: The maximum number of resources contained in the underlying API response. If page
             streaming is performed per- resource, this parameter does not affect the return value. If page
             streaming is performed per-page, this determines the maximum number of resources in a page.
-        :type page_size: int
         :param project_id: Project ID of the project that contains the instance. If set
             to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             ``retry`` is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
         parent = f"projects/{project_id}/locations/{location}"
@@ -466,14 +427,14 @@ class CloudMemorystoreHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def update_instance(
         self,
-        update_mask: Union[Dict, FieldMask],
-        instance: Union[Dict, Instance],
+        update_mask: dict | FieldMask,
+        instance: dict | Instance,
         project_id: str = PROVIDE_PROJECT_ID,
-        location: Optional[str] = None,
-        instance_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        location: str | None = None,
+        instance_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Updates the metadata and configuration of a specific Redis instance.
@@ -488,27 +449,19 @@ class CloudMemorystoreHook(GoogleBaseHook):
 
             If a dict is provided, it must be of the same form as the protobuf message
             :class:`~google.protobuf.field_mask_pb2.FieldMask`
-        :type update_mask: Union[Dict, google.protobuf.field_mask_pb2.FieldMask]
         :param instance: Required. Update description. Only fields specified in ``update_mask`` are updated.
 
             If a dict is provided, it must be of the same form as the protobuf message
             :class:`~google.cloud.redis_v1.types.Instance`
-        :type instance: Union[Dict, google.cloud.redis_v1.types.Instance]
         :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-        :type location: str
         :param instance_id: The logical name of the Redis instance in the customer project.
-        :type instance_id: str
         :param project_id: Project ID of the project that contains the instance. If set
             to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             ``retry`` is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
 
@@ -528,8 +481,9 @@ class CloudMemorystoreHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
-        result.result()
+        updated_instance = result.result()
         self.log.info("Instance updated: %s", instance.name)
+        return updated_instance
 
 
 class CloudMemorystoreMemcachedHook(GoogleBaseHook):
@@ -540,11 +494,9 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
     keyword arguments rather than positional.
 
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -553,45 +505,41 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account.
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
             delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
-        self._client: Optional[CloudMemcacheClient] = None
+        self._client: CloudMemcacheClient | None = None
 
     def get_conn(
         self,
     ):
         """Retrieves client library object that allow access to Cloud Memorystore Memcached service."""
         if not self._client:
-            self._client = CloudMemcacheClient(credentials=self._get_credentials())
+            self._client = CloudMemcacheClient(credentials=self.get_credentials())
         return self._client
 
     @staticmethod
     def _append_label(instance: cloud_memcache.Instance, key: str, val: str) -> cloud_memcache.Instance:
         """
-        Append labels to provided Instance type
+        Append labels to provided Instance type.
 
         Labels must fit the regex ``[a-z]([-a-z0-9]*[a-z0-9])?`` (current
          airflow version string follows semantic versioning spec: x.y.z).
 
         :param instance: The proto to append resource_label airflow
             version to
-        :type instance: google.cloud.memcache_v1beta2.types.cloud_memcache.Instance
         :param key: The key label
-        :type key: str
         :param val:
-        :type val: str
         :return: The cluster proto updated with new label
         """
         val = val.replace(".", "-").replace("+", "-")
@@ -606,34 +554,26 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
         project_id: str,
         location: str,
         instance_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Will update current set of Parameters to the set of specified nodes of the Memcached Instance.
 
         :param node_ids: Nodes to which we should apply the instance-level parameter group.
-        :type node_ids: Sequence[str]
         :param apply_all: Whether to apply instance-level parameter group to all nodes. If set to true,
             will explicitly restrict users from specifying any nodes, and apply parameter group updates
             to all nodes within the instance.
-        :type apply_all: bool
         :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-        :type location: str
         :param instance_id: The logical name of the Memcached instance in the customer project.
-        :type instance_id: str
         :param project_id: Project ID of the project that contains the instance. If set
             to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             ``retry`` is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
         metadata = metadata or ()
@@ -656,11 +596,11 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
         self,
         location: str,
         instance_id: str,
-        instance: Union[Dict, cloud_memcache.Instance],
+        instance: dict | cloud_memcache.Instance,
         project_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Creates a Memcached instance based on the specified tier and memory size.
@@ -669,7 +609,6 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
         <https://cloud.google.com/compute/docs/networks-and-firewalls#networks>`__.
 
         :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-        :type location: str
         :param instance_id: Required. The logical name of the Memcached instance in the customer project
             with the following restrictions:
 
@@ -678,23 +617,17 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
             -  Must be between 1-40 characters.
             -  Must end with a number or a letter.
             -  Must be unique within the customer project / location
-        :type instance_id: str
         :param instance: Required. A Memcached [Instance] resource
 
             If a dict is provided, it must be of the same form as the protobuf message
             :class:`~google.cloud.memcache_v1beta2.types.cloud_memcache.Instance`
-        :type instance: Union[Dict, google.cloud.memcache_v1beta2.types.cloud_memcache.Instance]
         :param project_id: Project ID of the project that contains the instance. If set
             to None or missing, the default project_id from the GCP connection is used.
-        :type project_id: str
         :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             ``retry`` is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
         metadata = metadata or ()
@@ -741,28 +674,22 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
         location: str,
         instance: str,
         project_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Deletes a specific Memcached instance.  Instance stops serving and data is deleted.
 
         :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-        :type location: str
         :param instance: The logical name of the Memcached instance in the customer project.
-        :type instance: str
         :param project_id:  Project ID of the project that contains the instance. If set
             to None or missing, the default project_id from the GCP connection is used.
-        :type project_id: str
         :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             ``retry`` is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
         metadata = metadata or ()
@@ -794,28 +721,22 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
         location: str,
         instance: str,
         project_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Gets the details of a specific Memcached instance.
 
         :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-        :type location: str
         :param instance: The logical name of the Memcached instance in the customer project.
-        :type instance: str
         :param project_id:  Project ID of the project that contains the instance. If set
             to None or missing, the default project_id from the GCP connection is used.
-        :type project_id: str
         :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             ``retry`` is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
         metadata = metadata or ()
@@ -829,30 +750,24 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
         self,
         location: str,
         project_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
-        Lists all Memcached instances owned by a project in either the specified location (region) or all
-        locations.
+        List Memcached instances owned by a project at the specified location (region) or all locations.
 
         :param location: The location of the Cloud Memorystore instance (for example europe-west1)
 
                 If it is specified as ``-`` (wildcard), then all regions available to the project are
                 queried, and the results are aggregated.
-        :type location: str
         :param project_id: Project ID of the project that contains the instance. If set
             to None or missing, the default project_id from the GCP connection is used.
-        :type project_id: str
         :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             ``retry`` is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
         metadata = metadata or ()
@@ -871,14 +786,14 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def update_instance(
         self,
-        update_mask: Union[Dict, FieldMask],
-        instance: Union[Dict, cloud_memcache.Instance],
+        update_mask: dict | FieldMask,
+        instance: dict | cloud_memcache.Instance,
         project_id: str,
-        location: Optional[str] = None,
-        instance_id: Optional[str] = None,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        location: str | None = None,
+        instance_id: str | None = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
         Updates the metadata and configuration of a specific Memcached instance.
@@ -890,28 +805,20 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
 
             If a dict is provided, it must be of the same form as the protobuf message
             :class:`~google.protobuf.field_mask_pb2.FieldMask`)
-        :type update_mask:
             Union[Dict, google.protobuf.field_mask_pb2.FieldMask]
         :param instance: Required. Update description. Only fields specified in ``update_mask`` are updated.
 
             If a dict is provided, it must be of the same form as the protobuf message
             :class:`~google.cloud.memcache_v1beta2.types.cloud_memcache.Instance`
-        :type instance: Union[Dict, google.cloud.memcache_v1beta2.types.cloud_memcache.Instance]
         :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-        :type location: str
         :param instance_id: The logical name of the Memcached instance in the customer project.
-        :type instance_id: str
         :param project_id: Project ID of the project that contains the instance. If set
             to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             ``retry`` is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
         metadata = metadata or ()
@@ -929,50 +836,44 @@ class CloudMemorystoreMemcachedHook(GoogleBaseHook):
         result = client.update_instance(
             update_mask=update_mask, resource=instance, retry=retry, timeout=timeout, metadata=metadata or ()
         )
-        result.result()
+        updated_instance = result.result()
         self.log.info("Instance updated: %s", instance.name)
+        return updated_instance
 
     @GoogleBaseHook.fallback_to_default_project_id
     def update_parameters(
         self,
-        update_mask: Union[Dict, FieldMask],
-        parameters: Union[Dict, cloud_memcache.MemcacheParameters],
+        update_mask: dict | FieldMask,
+        parameters: dict | cloud_memcache.MemcacheParameters,
         project_id: str,
         location: str,
         instance_id: str,
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
-        metadata: Sequence[Tuple[str, str]] = (),
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
     ):
         """
-        Updates the defined Memcached Parameters for an existing Instance. This method only stages the
-            parameters, it must be followed by apply_parameters to apply the parameters to nodes of
-            the Memcached Instance.
+        Update the defined Memcached Parameters for an existing Instance.
+
+        This method only stages the parameters, it must be followed by apply_parameters
+        to apply the parameters to nodes of the Memcached Instance.
 
         :param update_mask: Required. Mask of fields to update.
             If a dict is provided, it must be of the same form as the protobuf message
             :class:`~google.protobuf.field_mask_pb2.FieldMask`
-        :type update_mask:
             Union[Dict, google.protobuf.field_mask_pb2.FieldMask]
         :param parameters: The parameters to apply to the instance.
             If a dict is provided, it must be of the same form as the protobuf message
             :class:`~google.cloud.memcache_v1beta2.types.cloud_memcache.MemcacheParameters`
-        :type parameters: Union[Dict, google.cloud.memcache_v1beta2.types.cloud_memcache.MemcacheParameters]
         :param location: The location of the Cloud Memorystore instance (for example europe-west1)
-        :type location: str
         :param instance_id: The logical name of the Memcached instance in the customer project.
-        :type instance_id: str
         :param project_id: Project ID of the project that contains the instance. If set
             to None or missing, the default project_id from the Google Cloud connection is used.
-        :type project_id: str
         :param retry: A retry object used to retry requests. If ``None`` is specified, requests will not be
             retried.
-        :type retry: google.api_core.retry.Retry
         :param timeout: The amount of time, in seconds, to wait for the request to complete. Note that if
             ``retry`` is specified, the timeout applies to each individual attempt.
-        :type timeout: float
         :param metadata: Additional metadata that is provided to the method.
-        :type metadata: Sequence[Tuple[str, str]]
         """
         client = self.get_conn()
         metadata = metadata or ()
