@@ -15,7 +15,6 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
 """
 This module contains a Google Kubernetes Engine Hook.
 
@@ -24,11 +23,12 @@ This module contains a Google Kubernetes Engine Hook.
     gapic
     enums
 """
+from __future__ import annotations
 
 import json
 import time
 import warnings
-from typing import Dict, Optional, Sequence, Union
+from typing import Optional, Sequence
 
 from google.api_core.exceptions import AlreadyExists, NotFound
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
@@ -58,9 +58,9 @@ class GKEHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        location: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        location: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
@@ -73,7 +73,7 @@ class GKEHook(GoogleBaseHook):
     def get_cluster_manager_client(self) -> ClusterManagerClient:
         """Returns ClusterManagerClient."""
         if self._client is None:
-            self._client = ClusterManagerClient(credentials=self._get_credentials(), client_info=CLIENT_INFO)
+            self._client = ClusterManagerClient(credentials=self.get_credentials(), client_info=CLIENT_INFO)
         return self._client
 
     # To preserve backward compatibility
@@ -94,7 +94,7 @@ class GKEHook(GoogleBaseHook):
         )
         return self.get_conn()
 
-    def wait_for_operation(self, operation: Operation, project_id: Optional[str] = None) -> Operation:
+    def wait_for_operation(self, operation: Operation, project_id: str | None = None) -> Operation:
         """
         Given an operation, continuously fetches the status from Google Cloud until either
         completion or an error occurring
@@ -114,7 +114,7 @@ class GKEHook(GoogleBaseHook):
             operation = self.get_operation(operation.name, project_id=project_id or self.project_id)
         return operation
 
-    def get_operation(self, operation_name: str, project_id: Optional[str] = None) -> Operation:
+    def get_operation(self, operation_name: str, project_id: str | None = None) -> Operation:
         """
         Fetches the operation from Google Cloud
 
@@ -123,8 +123,10 @@ class GKEHook(GoogleBaseHook):
         :return: The new, updated operation from Google Cloud
         """
         return self.get_cluster_manager_client().get_operation(
-            name=f'projects/{project_id or self.project_id}'
-            + f'/locations/{self.location}/operations/{operation_name}'
+            name=(
+                f'projects/{project_id or self.project_id}'
+                f'/locations/{self.location}/operations/{operation_name}'
+            )
         )
 
     @staticmethod
@@ -150,9 +152,9 @@ class GKEHook(GoogleBaseHook):
         self,
         name: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
-    ) -> Optional[str]:
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+    ) -> str | None:
         """
         Deletes the cluster, including the Kubernetes endpoint and all
         worker nodes. Firewalls and routes that were configured during
@@ -178,7 +180,7 @@ class GKEHook(GoogleBaseHook):
                 retry=retry,
                 timeout=timeout,
             )
-            resource = self.wait_for_operation(resource)
+            resource = self.wait_for_operation(resource, project_id)
             # Returns server-defined url for the resource
             return resource.self_link
         except NotFound as error:
@@ -188,10 +190,10 @@ class GKEHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def create_cluster(
         self,
-        cluster: Union[Dict, Cluster, None],
+        cluster: dict | Cluster | None,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
     ) -> str:
         """
         Creates a cluster, consisting of the specified number and type of Google Compute
@@ -232,7 +234,7 @@ class GKEHook(GoogleBaseHook):
                 retry=retry,
                 timeout=timeout,
             )
-            resource = self.wait_for_operation(resource)
+            resource = self.wait_for_operation(resource, project_id)
 
             return resource.target_link
         except AlreadyExists as error:
@@ -244,8 +246,8 @@ class GKEHook(GoogleBaseHook):
         self,
         name: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Union[Retry, _MethodDefault] = DEFAULT,
-        timeout: Optional[float] = None,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
     ) -> Cluster:
         """
         Gets details of specified cluster
