@@ -16,7 +16,9 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Spanner Hook."""
-from typing import Callable, List, Optional, Sequence, Union
+from __future__ import annotations
+
+from typing import Callable, Sequence
 
 from google.api_core.exceptions import AlreadyExists, GoogleAPICallError
 from google.cloud.spanner_v1.client import Client
@@ -41,8 +43,8 @@ class SpannerHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
@@ -61,7 +63,7 @@ class SpannerHook(GoogleBaseHook):
         """
         if not self._client:
             self._client = Client(
-                project=project_id, credentials=self._get_credentials(), client_info=CLIENT_INFO
+                project=project_id, credentials=self.get_credentials(), client_info=CLIENT_INFO
             )
         return self._client
 
@@ -209,7 +211,7 @@ class SpannerHook(GoogleBaseHook):
         instance_id: str,
         database_id: str,
         project_id: str,
-    ) -> Optional[Database]:
+    ) -> Database | None:
         """
         Retrieves a database in Cloud Spanner. If the database does not exist
         in the specified instance, it returns None.
@@ -236,7 +238,7 @@ class SpannerHook(GoogleBaseHook):
         self,
         instance_id: str,
         database_id: str,
-        ddl_statements: List[str],
+        ddl_statements: list[str],
         project_id: str,
     ) -> None:
         """
@@ -269,9 +271,9 @@ class SpannerHook(GoogleBaseHook):
         self,
         instance_id: str,
         database_id: str,
-        ddl_statements: List[str],
+        ddl_statements: list[str],
         project_id: str,
-        operation_id: Optional[str] = None,
+        operation_id: str | None = None,
     ) -> None:
         """
         Updates DDL of a database in Cloud Spanner.
@@ -342,7 +344,7 @@ class SpannerHook(GoogleBaseHook):
         self,
         instance_id: str,
         database_id: str,
-        queries: List[str],
+        queries: list[str],
         project_id: str,
     ) -> None:
         """
@@ -360,6 +362,6 @@ class SpannerHook(GoogleBaseHook):
         ).run_in_transaction(lambda transaction: self._execute_sql_in_transaction(transaction, queries))
 
     @staticmethod
-    def _execute_sql_in_transaction(transaction: Transaction, queries: List[str]):
+    def _execute_sql_in_transaction(transaction: Transaction, queries: list[str]):
         for sql in queries:
             transaction.execute_update(sql)
