@@ -16,8 +16,11 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Speech Hook."""
-from typing import Dict, Optional, Sequence, Union
+from __future__ import annotations
 
+from typing import Sequence
+
+from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry
 from google.cloud.speech_v1 import SpeechClient
 from google.cloud.speech_v1.types import RecognitionAudio, RecognitionConfig
@@ -47,8 +50,8 @@ class CloudSpeechToTextHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
@@ -65,16 +68,16 @@ class CloudSpeechToTextHook(GoogleBaseHook):
         :rtype: google.cloud.speech_v1.SpeechClient
         """
         if not self._client:
-            self._client = SpeechClient(credentials=self._get_credentials(), client_info=CLIENT_INFO)
+            self._client = SpeechClient(credentials=self.get_credentials(), client_info=CLIENT_INFO)
         return self._client
 
     @GoogleBaseHook.quota_retry()
     def recognize_speech(
         self,
-        config: Union[Dict, RecognitionConfig],
-        audio: Union[Dict, RecognitionAudio],
-        retry: Optional[Retry] = None,
-        timeout: Optional[float] = None,
+        config: dict | RecognitionConfig,
+        audio: dict | RecognitionAudio,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
     ):
         """
         Recognizes audio input
