@@ -15,21 +15,17 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
+
 import os
-import sys
-from typing import Collection, Optional
-
-from airflow.providers.google.common.consts import CLIENT_INFO
-
-if sys.version_info >= (3, 8):
-    from functools import cached_property
-else:
-    from cached_property import cached_property
+from typing import Collection
 
 # not sure why but mypy complains on missing `storage` but it is clearly there and is importable
 from google.cloud import storage  # type: ignore[attr-defined]
 
+from airflow.compat.functools import cached_property
 from airflow.providers.google.cloud.utils.credentials_provider import get_credentials_and_project_id
+from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.utils.log.file_task_handler import FileTaskHandler
 from airflow.utils.log.logging_mixin import LoggingMixin
 
@@ -67,11 +63,11 @@ class GCSTaskHandler(FileTaskHandler, LoggingMixin):
         *,
         base_log_folder: str,
         gcs_log_folder: str,
-        filename_template: Optional[str] = None,
-        gcp_key_path: Optional[str] = None,
-        gcp_keyfile_dict: Optional[dict] = None,
-        gcp_scopes: Optional[Collection[str]] = _DEFAULT_SCOPESS,
-        project_id: Optional[str] = None,
+        filename_template: str | None = None,
+        gcp_key_path: str | None = None,
+        gcp_keyfile_dict: dict | None = None,
+        gcp_scopes: Collection[str] | None = _DEFAULT_SCOPESS,
+        project_id: str | None = None,
     ):
         super().__init__(base_log_folder, filename_template)
         self.remote_base = gcs_log_folder
@@ -156,7 +152,7 @@ class GCSTaskHandler(FileTaskHandler, LoggingMixin):
         except Exception as e:
             log = f'*** Unable to read remote log from {remote_loc}\n*** {str(e)}\n\n'
             self.log.error(log)
-            local_log, metadata = super()._read(ti, try_number)
+            local_log, metadata = super()._read(ti, try_number, metadata)
             log += local_log
             return log, metadata
 
