@@ -16,11 +16,14 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Spanner operators."""
-from typing import TYPE_CHECKING, List, Optional, Sequence, Union
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.spanner import SpannerHook
+from airflow.providers.google.cloud.links.spanner import SpannerDatabaseLink, SpannerInstanceLink
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -67,6 +70,7 @@ class SpannerDeployInstanceOperator(BaseOperator):
         'impersonation_chain',
     )
     # [END gcp_spanner_deploy_template_fields]
+    operator_extra_links = (SpannerInstanceLink(),)
 
     def __init__(
         self,
@@ -75,9 +79,9 @@ class SpannerDeployInstanceOperator(BaseOperator):
         configuration_name: str,
         node_count: int,
         display_name: str,
-        project_id: Optional[str] = None,
+        project_id: str | None = None,
         gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         self.instance_id = instance_id
@@ -96,7 +100,7 @@ class SpannerDeployInstanceOperator(BaseOperator):
         if not self.instance_id:
             raise AirflowException("The required parameter 'instance_id' is empty or None")
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = SpannerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -114,6 +118,12 @@ class SpannerDeployInstanceOperator(BaseOperator):
             node_count=self.node_count,
             display_name=self.display_name,
         )
+        SpannerInstanceLink.persist(
+            context=context,
+            task_instance=self,
+            instance_id=self.instance_id,
+            project_id=self.project_id or hook.project_id,
+        )
 
 
 class SpannerDeleteInstanceOperator(BaseOperator):
@@ -152,9 +162,9 @@ class SpannerDeleteInstanceOperator(BaseOperator):
         self,
         *,
         instance_id: str,
-        project_id: Optional[str] = None,
+        project_id: str | None = None,
         gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         self.instance_id = instance_id
@@ -170,7 +180,7 @@ class SpannerDeleteInstanceOperator(BaseOperator):
         if not self.instance_id:
             raise AirflowException("The required parameter 'instance_id' is empty or None")
 
-    def execute(self, context: 'Context') -> Optional[bool]:
+    def execute(self, context: Context) -> bool | None:
         hook = SpannerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -223,16 +233,17 @@ class SpannerQueryDatabaseInstanceOperator(BaseOperator):
     template_ext: Sequence[str] = ('.sql',)
     template_fields_renderers = {'query': 'sql'}
     # [END gcp_spanner_query_template_fields]
+    operator_extra_links = (SpannerDatabaseLink(),)
 
     def __init__(
         self,
         *,
         instance_id: str,
         database_id: str,
-        query: Union[str, List[str]],
-        project_id: Optional[str] = None,
+        query: str | list[str],
+        project_id: str | None = None,
         gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         self.instance_id = instance_id
@@ -254,7 +265,7 @@ class SpannerQueryDatabaseInstanceOperator(BaseOperator):
         if not self.query:
             raise AirflowException("The required parameter 'query' is empty")
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = SpannerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -277,9 +288,16 @@ class SpannerQueryDatabaseInstanceOperator(BaseOperator):
             database_id=self.database_id,
             queries=queries,
         )
+        SpannerDatabaseLink.persist(
+            context=context,
+            task_instance=self,
+            instance_id=self.instance_id,
+            database_id=self.database_id,
+            project_id=self.project_id or hook.project_id,
+        )
 
     @staticmethod
-    def sanitize_queries(queries: List[str]) -> None:
+    def sanitize_queries(queries: list[str]) -> None:
         """
         Drops empty query in queries.
 
@@ -327,16 +345,17 @@ class SpannerDeployDatabaseInstanceOperator(BaseOperator):
     template_ext: Sequence[str] = ('.sql',)
     template_fields_renderers = {'ddl_statements': 'sql'}
     # [END gcp_spanner_database_deploy_template_fields]
+    operator_extra_links = (SpannerDatabaseLink(),)
 
     def __init__(
         self,
         *,
         instance_id: str,
         database_id: str,
-        ddl_statements: List[str],
-        project_id: Optional[str] = None,
+        ddl_statements: list[str],
+        project_id: str | None = None,
         gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         self.instance_id = instance_id
@@ -356,11 +375,18 @@ class SpannerDeployDatabaseInstanceOperator(BaseOperator):
         if not self.database_id:
             raise AirflowException("The required parameter 'database_id' is empty or None")
 
-    def execute(self, context: 'Context') -> Optional[bool]:
+    def execute(self, context: Context) -> bool | None:
         hook = SpannerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
         )
+        SpannerDatabaseLink.persist(
+            context=context,
+            task_instance=self,
+            instance_id=self.instance_id,
+            database_id=self.database_id,
+            project_id=self.project_id or hook.project_id,
+        )
         if not hook.get_database(
             project_id=self.project_id, instance_id=self.instance_id, database_id=self.database_id
         ):
@@ -425,17 +451,18 @@ class SpannerUpdateDatabaseInstanceOperator(BaseOperator):
     template_ext: Sequence[str] = ('.sql',)
     template_fields_renderers = {'ddl_statements': 'sql'}
     # [END gcp_spanner_database_update_template_fields]
+    operator_extra_links = (SpannerDatabaseLink(),)
 
     def __init__(
         self,
         *,
         instance_id: str,
         database_id: str,
-        ddl_statements: List[str],
-        project_id: Optional[str] = None,
-        operation_id: Optional[str] = None,
+        ddl_statements: list[str],
+        project_id: str | None = None,
+        operation_id: str | None = None,
         gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         self.instance_id = instance_id
@@ -458,7 +485,7 @@ class SpannerUpdateDatabaseInstanceOperator(BaseOperator):
         if not self.ddl_statements:
             raise AirflowException("The required parameter 'ddl_statements' is empty or None")
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = SpannerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -472,6 +499,13 @@ class SpannerUpdateDatabaseInstanceOperator(BaseOperator):
                 f"Create the database first before you can update it."
             )
         else:
+            SpannerDatabaseLink.persist(
+                context=context,
+                task_instance=self,
+                instance_id=self.instance_id,
+                database_id=self.database_id,
+                project_id=self.project_id or hook.project_id,
+            )
             return hook.update_database(
                 project_id=self.project_id,
                 instance_id=self.instance_id,
@@ -519,9 +553,9 @@ class SpannerDeleteDatabaseInstanceOperator(BaseOperator):
         *,
         instance_id: str,
         database_id: str,
-        project_id: Optional[str] = None,
+        project_id: str | None = None,
         gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         self.instance_id = instance_id
@@ -540,7 +574,7 @@ class SpannerDeleteDatabaseInstanceOperator(BaseOperator):
         if not self.database_id:
             raise AirflowException("The required parameter 'database_id' is empty or None")
 
-    def execute(self, context: 'Context') -> bool:
+    def execute(self, context: Context) -> bool:
         hook = SpannerHook(
             gcp_conn_id=self.gcp_conn_id,
             impersonation_chain=self.impersonation_chain,
