@@ -14,10 +14,12 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
 """Objects relating to sourcing connections from Google Cloud Secrets Manager"""
+from __future__ import annotations
+
 import logging
-from typing import Optional
+import re
+import warnings
 
 from google.auth.exceptions import DefaultCredentialsError
 
@@ -26,12 +28,18 @@ from airflow.providers.google.cloud._internal_client.secret_manager_client impor
 from airflow.providers.google.cloud.utils.credentials_provider import get_credentials_and_project_id
 from airflow.secrets import BaseSecretsBackend
 from airflow.utils.log.logging_mixin import LoggingMixin
+from airflow.version import version as airflow_version
 
 log = logging.getLogger(__name__)
 
 SECRET_ID_PATTERN = r"^[a-zA-Z0-9-_]*$"
 
 
+def _parse_version(val):
+    val = re.sub(r'(\d+\.\d+\.\d+).*', lambda x: x.group(1), val)
+    return tuple(int(x) for x in val.split('.'))
+
+
 class CloudSecretManagerBackend(BaseSecretsBackend, LoggingMixin):
     """
     Retrieves Connection object from Google Cloud Secrets Manager
@@ -56,26 +64,18 @@ class CloudSecretManagerBackend(BaseSecretsBackend, LoggingMixin):
 
     :param connections_prefix: Specifies the prefix of the secret to read to get Connections.
         If set to None (null), requests for connections will not be sent to GCP Secrets Manager
-    :type connections_prefix: str
     :param variables_prefix: Specifies the prefix of the secret to read to get Variables.
         If set to None (null), requests for variables will not be sent to GCP Secrets Manager
-    :type variables_prefix: str
     :param config_prefix: Specifies the prefix of the secret to read to get Airflow Configurations
         containing secrets.
         If set to None (null), requests for configurations will not be sent to GCP Secrets Manager
-    :type config_prefix: str
     :param gcp_key_path: Path to Google Cloud Service Account key file (JSON). Mutually exclusive with
         gcp_keyfile_dict. use default credentials in the current environment if not provided.
-    :type gcp_key_path: str
     :param gcp_keyfile_dict: Dictionary of keyfile parameters. Mutually exclusive with gcp_key_path.
-    :type gcp_keyfile_dict: dict
     :param gcp_scopes: Comma-separated string containing OAuth2 scopes
-    :type gcp_scopes: str
     :param project_id: Project ID to read the secrets from. If not passed, the project ID from credentials
         will be used.
-    :type project_id: str
     :param sep: Separator used to concatenate connections_prefix and conn_id. Default: "-"
-    :type sep: str
     """
 
     def __init__(
@@ -83,10 +83,10 @@ class CloudSecretManagerBackend(BaseSecretsBackend, LoggingMixin):
         connections_prefix: str = "airflow-connections",
         variables_prefix: str = "airflow-variables",
         config_prefix: str = "airflow-config",
-        gcp_keyfile_dict: Optional[dict] = None,
-        gcp_key_path: Optional[str] = None,
-        gcp_scopes: Optional[str] = None,
-        project_id: Optional[str] = None,
+        gcp_keyfile_dict: dict | None = None,
+        gcp_key_path: str | None = None,
+        gcp_scopes: str | None = None,
+        project_id: str | None = None,
         sep: str = "-",
         **kwargs,
     ) -> None:
@@ -129,19 +129,36 @@ class CloudSecretManagerBackend(BaseSecretsBackend, LoggingMixin):
         prefix = self.connections_prefix + self.sep
         return _SecretManagerClient.is_valid_secret_name(prefix)
 
-    def get_conn_uri(self, conn_id: str) -> Optional[str]:
+    def get_conn_value(self, conn_id: str) -> str | None:
         """
-        Get secret value from the SecretManager.
+        Get serialized representation of Connection
 
         :param conn_id: connection id
-        :type conn_id: str
         """
         if self.connections_prefix is None:
             return None
 
         return self._get_secret(self.connections_prefix, conn_id)
 
-    def get_variable(self, key: str) -> Optional[str]:
+    def get_conn_uri(self, conn_id: str) -> str | None:
+        """
+        Return URI representation of Connection conn_id.
+
+        As of Airflow version 2.3.0 this method is deprecated.
+
+        :param conn_id: the connection id
+        :return: deserialized Connection
+        """
+        if _parse_version(airflow_version) >= (2, 3):
+            warnings.warn(
+                f"Method `{self.__class__.__name__}.get_conn_uri` is deprecated and will be removed "
+                "in a future release.  Please use method `get_conn_value` instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+        return self.get_conn_value(conn_id)
+
+    def get_variable(self, key: str) -> str | None:
         """
         Get Airflow Variable from Environment Variable
 
@@ -153,7 +170,7 @@ class CloudSecretManagerBackend(BaseSecretsBackend, LoggingMixin):
 
         return self._get_secret(self.variables_prefix, key)
 
-    def get_config(self, key: str) -> Optional[str]:
+    def get_config(self, key: str) -> str | None:
         """
         Get Airflow Configuration
 
@@ -165,14 +182,12 @@ class CloudSecretManagerBackend(BaseSecretsBackend, LoggingMixin):
 
         return self._get_secret(self.config_prefix, key)
 
-    def _get_secret(self, path_prefix: str, secret_id: str) -> Optional[str]:
+    def _get_secret(self, path_prefix: str, secret_id: str) -> str | None:
         """
         Get secret value from the SecretManager based on prefix.
 
         :param path_prefix: Prefix for the Path to get Secret
-        :type path_prefix: str
         :param secret_id: Secret Key
-        :type secret_id: str
         """
         secret_id = self.build_path(path_prefix, secret_id, self.sep)
         return self.client.get_secret(secret_id=secret_id, project_id=self.project_id)
