@@ -16,7 +16,9 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Transfer sensor."""
-from typing import TYPE_CHECKING, Optional, Sequence, Set, Union
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.providers.google.cloud.hooks.cloud_storage_transfer_service import (
     COUNTERS,
@@ -24,6 +26,7 @@ from airflow.providers.google.cloud.hooks.cloud_storage_transfer_service import
     NAME,
     CloudDataTransferServiceHook,
 )
+from airflow.providers.google.cloud.links.cloud_storage_transfer import CloudStorageTransferJobLink
 from airflow.sensors.base import BaseSensorOperator
 
 if TYPE_CHECKING:
@@ -40,17 +43,13 @@ class CloudDataTransferServiceJobStatusSensor(BaseSensorOperator):
         :ref:`howto/operator:CloudDataTransferServiceJobStatusSensor`
 
     :param job_name: The name of the transfer job
-    :type job_name: str
     :param expected_statuses: The expected state of the operation.
         See:
         https://cloud.google.com/storage-transfer/docs/reference/rest/v1/transferOperations#Status
-    :type expected_statuses: set[str] or string
     :param project_id: (Optional) the ID of the project that owns the Transfer
         Job. If set to None or missing, the default project_id from the Google Cloud
         connection is used.
-    :type project_id: str
     :param gcp_conn_id: The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -59,7 +58,6 @@ class CloudDataTransferServiceJobStatusSensor(BaseSensorOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START gcp_transfer_job_sensor_template_fields]
@@ -68,15 +66,16 @@ class CloudDataTransferServiceJobStatusSensor(BaseSensorOperator):
         'impersonation_chain',
     )
     # [END gcp_transfer_job_sensor_template_fields]
+    operator_extra_links = (CloudStorageTransferJobLink(),)
 
     def __init__(
         self,
         *,
         job_name: str,
-        expected_statuses: Union[Set[str], str],
-        project_id: Optional[str] = None,
+        expected_statuses: set[str] | str,
+        project_id: str | None = None,
         gcp_conn_id: str = 'google_cloud_default',
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -88,7 +87,7 @@ class CloudDataTransferServiceJobStatusSensor(BaseSensorOperator):
         self.gcp_cloud_conn_id = gcp_conn_id
         self.impersonation_chain = impersonation_chain
 
-    def poke(self, context: 'Context') -> bool:
+    def poke(self, context: Context) -> bool:
         hook = CloudDataTransferServiceHook(
             gcp_conn_id=self.gcp_cloud_conn_id,
             impersonation_chain=self.impersonation_chain,
@@ -106,4 +105,13 @@ class CloudDataTransferServiceJobStatusSensor(BaseSensorOperator):
         if check:
             self.xcom_push(key="sensed_operations", value=operations, context=context)
 
+        project_id = self.project_id or hook.project_id
+        if project_id:
+            CloudStorageTransferJobLink.persist(
+                context=context,
+                task_instance=self,
+                project_id=project_id,
+                job_name=self.job_name,
+            )
+
         return check
