@@ -14,7 +14,9 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import TYPE_CHECKING, Any, Dict, List, Optional
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Any
 
 from airflow.models import BaseOperator
 from airflow.providers.google.leveldb.hooks.leveldb import LevelDBHook
@@ -33,22 +35,14 @@ class LevelDBOperator(BaseOperator):
 
         :param command: command of plyvel(python wrap for leveldb) for DB object e.g.
             ``"put"``, ``"get"``, ``"delete"``, ``"write_batch"``.
-        :type command: str
         :param key: key for command(put,get,delete) execution(, e.g. ``b'key'``, ``b'another-key'``)
-        :type key: bytes
         :param value: value for command(put) execution(bytes, e.g. ``b'value'``, ``b'another-value'``)
-        :type value: Optional[bytes]
         :param keys: keys for command(write_batch) execution(List[bytes], e.g. ``[b'key', b'another-key'])``
-        :type keys: Optional[List[bytes]]
         :param values: values for command(write_batch) execution e.g. ``[b'value'``, ``b'another-value']``
-        :type values: Optional[List[bytes]]
         :param leveldb_conn_id:
-        :type leveldb_conn_id: str
         :param create_if_missing: whether a new database should be created if needed
-        :type create_if_missing: bool
         :param create_db_extra_options: extra options of creation LevelDBOperator. See more in the link below
             `Plyvel DB <https://plyvel.readthedocs.io/en/latest/api.html#DB>`__
-        :type create_db_extra_options: Optional[Dict[str, Any]]
     """
 
     def __init__(
@@ -56,13 +50,13 @@ class LevelDBOperator(BaseOperator):
         *,
         command: str,
         key: bytes,
-        value: Optional[bytes] = None,
-        keys: Optional[List[bytes]] = None,
-        values: Optional[List[bytes]] = None,
+        value: bytes | None = None,
+        keys: list[bytes] | None = None,
+        values: list[bytes] | None = None,
         leveldb_conn_id: str = 'leveldb_default',
         name: str = '/tmp/testdb/',
         create_if_missing: bool = True,
-        create_db_extra_options: Optional[Dict[str, Any]] = None,
+        create_db_extra_options: dict[str, Any] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -76,7 +70,7 @@ class LevelDBOperator(BaseOperator):
         self.create_if_missing = create_if_missing
         self.create_db_extra_options = create_db_extra_options or {}
 
-    def execute(self, context: 'Context') -> Optional[str]:
+    def execute(self, context: Context) -> str | None:
         """
         Execute command in LevelDB
 
