@@ -15,10 +15,10 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
 """This module contains a Google Sheets API hook"""
+from __future__ import annotations
 
-from typing import Any, Dict, List, Optional, Sequence, Union
+from typing import Any, Sequence
 
 from googleapiclient.discovery import build
 
@@ -33,13 +33,10 @@ class GSheetsHook(GoogleBaseHook):
     https://developers.google.com/sheets/api/guides/values
 
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :type gcp_conn_id: str
     :param api_version: API Version
-    :type api_version: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -48,15 +45,14 @@ class GSheetsHook(GoogleBaseHook):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account.
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     def __init__(
         self,
         gcp_conn_id: str = 'google_cloud_default',
         api_version: str = 'v4',
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
@@ -94,18 +90,13 @@ class GSheetsHook(GoogleBaseHook):
         https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.values/get
 
         :param spreadsheet_id: The Google Sheet ID to interact with
-        :type spreadsheet_id: str
         :param range_: The A1 notation of the values to retrieve.
-        :type range_: str
         :param major_dimension: Indicates which dimension an operation should apply to.
             DIMENSION_UNSPECIFIED, ROWS, or COLUMNS
-        :type major_dimension: str
         :param value_render_option: Determines how values should be rendered in the output.
             FORMATTED_VALUE, UNFORMATTED_VALUE, or FORMULA
-        :type value_render_option: str
         :param date_time_render_option: Determines how dates should be rendered in the output.
             SERIAL_NUMBER or FORMATTED_STRING
-        :type date_time_render_option: str
         :return: An array of sheet values from the specified sheet.
         :rtype: List
         """
@@ -129,7 +120,7 @@ class GSheetsHook(GoogleBaseHook):
     def batch_get_values(
         self,
         spreadsheet_id: str,
-        ranges: List,
+        ranges: list,
         major_dimension: str = 'DIMENSION_UNSPECIFIED',
         value_render_option: str = 'FORMATTED_VALUE',
         date_time_render_option: str = 'SERIAL_NUMBER',
@@ -139,18 +130,13 @@ class GSheetsHook(GoogleBaseHook):
         https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.values/batchGet
 
         :param spreadsheet_id: The Google Sheet ID to interact with
-        :type spreadsheet_id: str
         :param ranges: The A1 notation of the values to retrieve.
-        :type ranges: List
         :param major_dimension: Indicates which dimension an operation should apply to.
             DIMENSION_UNSPECIFIED, ROWS, or COLUMNS
-        :type major_dimension: str
         :param value_render_option: Determines how values should be rendered in the output.
             FORMATTED_VALUE, UNFORMATTED_VALUE, or FORMULA
-        :type value_render_option: str
         :param date_time_render_option: Determines how dates should be rendered in the output.
             SERIAL_NUMBER or FORMATTED_STRING
-        :type date_time_render_option: str
         :return: Google Sheets API response.
         :rtype: Dict
         """
@@ -175,7 +161,7 @@ class GSheetsHook(GoogleBaseHook):
         self,
         spreadsheet_id: str,
         range_: str,
-        values: List,
+        values: list,
         major_dimension: str = 'ROWS',
         value_input_option: str = 'RAW',
         include_values_in_response: bool = False,
@@ -187,26 +173,18 @@ class GSheetsHook(GoogleBaseHook):
         https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.values/update
 
         :param spreadsheet_id: The Google Sheet ID to interact with.
-        :type spreadsheet_id: str
         :param range_: The A1 notation of the values to retrieve.
-        :type range_: str
         :param values: Data within a range of the spreadsheet.
-        :type values: List
         :param major_dimension: Indicates which dimension an operation should apply to.
             DIMENSION_UNSPECIFIED, ROWS, or COLUMNS
-        :type major_dimension: str
         :param value_input_option: Determines how input data should be interpreted.
             RAW or USER_ENTERED
-        :type value_input_option: str
         :param include_values_in_response: Determines if the update response should
             include the values of the cells that were updated.
-        :type include_values_in_response: bool
         :param value_render_option: Determines how values should be rendered in the output.
             FORMATTED_VALUE, UNFORMATTED_VALUE, or FORMULA
-        :type value_render_option: str
         :param date_time_render_option: Determines how dates should be rendered in the output.
             SERIAL_NUMBER or FORMATTED_STRING
-        :type date_time_render_option: str
         :return: Google Sheets API response.
         :rtype: Dict
         """
@@ -233,8 +211,8 @@ class GSheetsHook(GoogleBaseHook):
     def batch_update_values(
         self,
         spreadsheet_id: str,
-        ranges: List,
-        values: List,
+        ranges: list,
+        values: list,
         major_dimension: str = 'ROWS',
         value_input_option: str = 'RAW',
         include_values_in_response: bool = False,
@@ -246,26 +224,18 @@ class GSheetsHook(GoogleBaseHook):
         https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.values/batchUpdate
 
         :param spreadsheet_id: The Google Sheet ID to interact with
-        :type spreadsheet_id: str
         :param ranges: The A1 notation of the values to retrieve.
-        :type ranges: List
         :param values: Data within a range of the spreadsheet.
-        :type values: List
         :param major_dimension: Indicates which dimension an operation should apply to.
             DIMENSION_UNSPECIFIED, ROWS, or COLUMNS
-        :type major_dimension: str
         :param value_input_option: Determines how input data should be interpreted.
             RAW or USER_ENTERED
-        :type value_input_option: str
         :param include_values_in_response: Determines if the update response should
             include the values of the cells that were updated.
-        :type include_values_in_response: bool
         :param value_render_option: Determines how values should be rendered in the output.
             FORMATTED_VALUE, UNFORMATTED_VALUE, or FORMULA
-        :type value_render_option: str
         :param date_time_render_option: Determines how dates should be rendered in the output.
             SERIAL_NUMBER or FORMATTED_STRING
-        :type date_time_render_option: str
         :return: Google Sheets API response.
         :rtype: Dict
         """
@@ -300,7 +270,7 @@ class GSheetsHook(GoogleBaseHook):
         self,
         spreadsheet_id: str,
         range_: str,
-        values: List,
+        values: list,
         major_dimension: str = 'ROWS',
         value_input_option: str = 'RAW',
         insert_data_option: str = 'OVERWRITE',
@@ -313,29 +283,20 @@ class GSheetsHook(GoogleBaseHook):
         https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.values/append
 
         :param spreadsheet_id: The Google Sheet ID to interact with
-        :type spreadsheet_id: str
         :param range_: The A1 notation of the values to retrieve.
-        :type range_: str
         :param values: Data within a range of the spreadsheet.
-        :type values: List
         :param major_dimension: Indicates which dimension an operation should apply to.
             DIMENSION_UNSPECIFIED, ROWS, or COLUMNS
-        :type major_dimension: str
         :param value_input_option: Determines how input data should be interpreted.
             RAW or USER_ENTERED
-        :type value_input_option: str
         :param insert_data_option: Determines how existing data is changed when new data is input.
             OVERWRITE or INSERT_ROWS
-        :type insert_data_option: str
         :param include_values_in_response: Determines if the update response should
             include the values of the cells that were updated.
-        :type include_values_in_response: bool
         :param value_render_option: Determines how values should be rendered in the output.
             FORMATTED_VALUE, UNFORMATTED_VALUE, or FORMULA
-        :type value_render_option: str
         :param date_time_render_option: Determines how dates should be rendered in the output.
             SERIAL_NUMBER or FORMATTED_STRING
-        :type date_time_render_option: str
         :return: Google Sheets API response.
         :rtype: Dict
         """
@@ -366,9 +327,7 @@ class GSheetsHook(GoogleBaseHook):
         https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.values/clear
 
         :param spreadsheet_id: The Google Sheet ID to interact with
-        :type spreadsheet_id: str
         :param range_: The A1 notation of the values to retrieve.
-        :type range_: str
         :return: Google Sheets API response.
         :rtype: Dict
         """
@@ -389,9 +348,7 @@ class GSheetsHook(GoogleBaseHook):
         https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets.values/batchClear
 
         :param spreadsheet_id: The Google Sheet ID to interact with
-        :type spreadsheet_id: str
         :param ranges: The A1 notation of the values to retrieve.
-        :type ranges: List
         :return: Google Sheets API response.
         :rtype: Dict
         """
@@ -412,7 +369,6 @@ class GSheetsHook(GoogleBaseHook):
         Retrieves spreadsheet matching the given id.
 
         :param spreadsheet_id: The spreadsheet id.
-        :type spreadsheet_id: str
         :return: An spreadsheet that matches the sheet filter.
         """
         response = (
@@ -423,14 +379,12 @@ class GSheetsHook(GoogleBaseHook):
         )
         return response
 
-    def get_sheet_titles(self, spreadsheet_id: str, sheet_filter: Optional[List[str]] = None):
+    def get_sheet_titles(self, spreadsheet_id: str, sheet_filter: list[str] | None = None):
         """
         Retrieves the sheet titles from a spreadsheet matching the given id and sheet filter.
 
         :param spreadsheet_id: The spreadsheet id.
-        :type spreadsheet_id: str
         :param sheet_filter: List of sheet title to retrieve from sheet.
-        :type sheet_filter: List[str]
         :return: An list of sheet titles from the specified sheet that match
             the sheet filter.
         """
@@ -446,13 +400,12 @@ class GSheetsHook(GoogleBaseHook):
             titles = [sh['properties']['title'] for sh in response['sheets']]
         return titles
 
-    def create_spreadsheet(self, spreadsheet: Dict[str, Any]) -> Dict[str, Any]:
+    def create_spreadsheet(self, spreadsheet: dict[str, Any]) -> dict[str, Any]:
         """
         Creates a spreadsheet, returning the newly created spreadsheet.
 
         :param spreadsheet: an instance of Spreadsheet
             https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets#Spreadsheet
-        :type spreadsheet: Dict[str, Any]
         :return: An spreadsheet object.
         """
         self.log.info("Creating spreadsheet: %s", spreadsheet['properties']['title'])
